#include <iostream>
#include <vector>
#include <set>
#include <queue>
#include <stack>
#include <math.h>
#include <random>
#include <chrono>
#include <map>
using namespace std;

typedef long long ll;
typedef unsigned long long ull;

const int INF = 1000 * 1000 * 1000;
const ll LLINF = 1LL * INF * INF;

mt19937 gen(chrono::high_resolution_clock::now().time_since_epoch().count());

struct pt
{
	double x, y;

	pt()
	{
		x = y = 0;
	}

	pt(double x, double y)
	{
		this->x = x;
		this->y = y;
	}
};

struct line
{
	double a, b, c;

	line()
	{
		a = b = c = 0;
	}


	line(pt p, pt q)
	{
		a = p.x - q.x;
		b = q.y - p.y;
		c = p.x * q.y - p.y * q.x;

		double norm = sqrt(a * a + b * b);
		a /= norm;
		b /= norm;
		c /= norm;
	}
};

pt intersect(line a, line b)
{
	double x = (a.c * b.b - b.c * a.b) / (a.a * b.b - b.a * a.b);
	double y = (a.a * b.c - b.a * a.c) / (a.a * b.b - b.a * a.b);

	return pt(x, y);
}

double cross(const pt& a, const pt& b, const pt& c)
{
	return (a.x - c.x) * (b.y - c.y) - (a.y - c.y) * (b.x - c.x);
}

int cw(const pt& a, const pt& b, const pt& c)
{
	return cross(a, b, c) < 0;
}

int ccw(const pt& a, const pt& b, const pt& c)
{
	return cross(a, b, c) > 0;
}

pt operator+(const pt& a, const pt& b)
{
	return pt(a.x + b.x, a.y + b.y);
}

pt operator-(const pt& a, const pt& b)
{
	return pt(a.x - b.x, a.y - b.y);
}

pt operator/(const pt& a, double d)
{
	return pt(a.x / d, a.y / d);
}

struct pp
{
	pt p;
	int id;
};

bool operator<(const pt& a, const pt& b)
{
	return a.x < b.x || (a.x == b.x && a.y < b.y);
}

bool operator<(const pp& a, const pp& b)
{
	return a.p < b.p;
}

vector<pp> convexHull(vector<pp> pts)
{
	sort(pts.begin(), pts.end());
	vector<pp> up, down;
	pp p0 = pts[0];
	pp p1 = pts.back();
	up.push_back(p0);
	down.push_back(p0);

	for (int i = 1; i < pts.size(); i++)
	{
		if (i == pts.size() - 1 || cw(p0.p, pts[i].p, p1.p))
		{
			while (up.size() > 1 && !cw(up[up.size() - 2].p, up.back().p, pts[i].p))
				up.pop_back();

			up.push_back(pts[i]);
		}

		if (i == pts.size() - 1 || ccw(p0.p, pts[i].p, p1.p))
		{
			while (down.size() > 1 && !ccw(down[down.size() - 2].p, down.back().p, pts[i].p))
				down.pop_back();

			down.push_back(pts[i]);
		}
	}

	for (int i = (int)down.size() - 2; i > 0; i--)
		up.push_back(down[i]);

	return up;
}

double dist(const pt& a, const pt& b)
{
	return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

double getY(double dy, double dx, double x)
{
	return dy * x / dx;
}

int main()
{
	cin.tie(0);
	ios_base::sync_with_stdio(0);

	int H, W;
	int n;
	cin >> W >> H >> n;

	vector<pt> pts(n);

	for (int i = 0; i < n; i++)
	{
		cin >> pts[i].x >> pts[i].y;
	}

	pts.push_back(pt(pts[0].x, -1e-8));
	pts.push_back(pt(-1e-8, pts[0].y));
	pts.push_back(pt(W, pts[0].y));
	pts.push_back(pt(pts[0].x, H));

	vector<pp> hull;

	for (int i = 1; i < pts.size(); i++)
	{
		double len = dist(pts[0], pts[i]);
		pt p = pts[i] - pts[0];

		if (len < 1e-8)
			len = 1;

		p = p / (len * len);
		hull.push_back({ p, i });
	}

	hull = convexHull(hull);

	vector<line> lines;

	for (int i = 0; i < hull.size(); i++)
	{
		pt p = pts[hull[i].id];
		pt mid = (p + pts[0]) / 2;
		pt rot = p - mid;
		rot = pt(rot.y, -rot.x);
		rot = rot + mid;
		lines.push_back(line(mid, rot));
	}

	lines.push_back(lines[0]);
	pts = {};

	for (int i = 0; i + 1 < lines.size(); i++)
	{
		pts.push_back(intersect(lines[i], lines[i + 1]));
	}

	sort(pts.begin(), pts.end());
	pt p0 = pts[0], p1 = pts.back();

	ll res = 0;

	vector<pt> top, down;
	top.push_back(p0);
	down.push_back(p0);

	for (int i = 1; i < pts.size(); i++)
	{
		if (i == pts.size() - 1 || cw(p0, pts[i], p1))
		{
			top.push_back(pts[i]);
		}

		if (i == pts.size() - 1 || ccw(p0, pts[i], p1))
		{
			down.push_back(pts[i]);
		}
	}

	int topI = 0, downI = 0;

	for (int i = 0; i <= W; i++)
	{
		double topY = -1, downY = -1;

		if (i  + 1e-8 < min(top[topI].x, down[downI].x)/* || i - 1e-8 > max(top[topI + 1].x, down[downI + 1].x)*/)
			continue;

		while (topI + 1 < top.size() && !(top[topI].x - 1e-8 <= i && i <= top[topI + 1].x + 1e-8))
			topI++;

		while (downI + 1 < down.size() && !(down[downI].x - 1e-8 <= i && i <= down[downI + 1].x + 1e-8))
			downI++;


		if (topI == top.size() - 1 || downI == down.size() - 1 || i + 1e-8 < min(top[topI].x, down[downI].x) || i - 1e-8 > max(top[topI + 1].x, down[downI + 1].x))
			continue;

		topY = getY(top[topI + 1].y - top[topI].y, top[topI + 1].x - top[topI].x, i - top[topI].x) + top[topI].y + 1e-8;
		downY = getY(down[downI + 1].y - down[downI].y, down[downI + 1].x - down[downI].x, i - down[downI].x) + down[downI].y - 1e-8;

		res += max(0.0, floor(topY) - ceil(downY) + 1);
	}

	cout << res;

	return 0;
}